clc;
close all;
clear all;

% change debug to 1 to create debugging file, otherwise debug=0
debug = 0;

if (debug)
    debug_file = fopen('debug.dat', 'wt'); 
end

% user input
file = 'MMB_test_20_mmb.dat';
disp_node1 = 79;
disp_node2 = 159;
f_node1 = 261;
f_node2 = 20835;

% open dat files
fid = fopen(file);

% Initialization
i = 0;
numSteps = 0;

% Read data
while ( ~feof(fid) )   
    tline = fgetl(fid);
    i = i+1;
    
    % read until a new nodal data is reached
    if (regexpi(tline, 'N O D E   O U T P U T')>0)
        
        numSteps = numSteps + 1;
        tline = fgetl(fid);
        i = i+1;
        
        % skip lines that do not contain all numbers
        while(isempty(str2num(tline)))
            tline = fgetl(fid);    
            i = i+1;
        end

        % reached nodal displacements
        while(~isempty(str2num(tline)))
            
            % read in displacements
            data_u = sscanf(tline, '%d %lf %e', [1,3]);
            
            if (debug)
                fprintf(debug_file, '%d\t%e\t%e\n', data_u(1), data_u(2), data_u(3));
            end
            
            tline = fgetl(fid);
            i = i+1;
            
            % store difference between displacement at disp_node1 and
            % disp_node2 in disp
            if (data_u(1) == disp_node1)
                opening(numSteps) = -data_u(3);
            end
            if (data_u(1) == disp_node2)
                opening(numSteps) = opening(numSteps) + data_u(3);
            end
        end
        % end of displacements
        
        if (debug)
            fprintf(debug_file, '\n');
        end
        
        % skip lines that do not contain all numbers
        while(isempty(str2num(tline)))
            tline = fgetl(fid);    
            i = i+1;
        end
        
        % reached nodal forces
        while(~isempty(str2num(tline)))
            
            % read in forces
            data_f = sscanf(tline, '%d %lf %e', [1,3]);
            
            if (debug)
                fprintf(debug_file, '%d\t%e\t%e\n', data_f(1), data_f(2), data_f(3));
            end
            
            tline = fgetl(fid);
            i = i+1;
            
            % store sum of forces at f_node1 and f_node2 in force
            if (data_f(1) == f_node1)
                force(numSteps) = data_f(3);
            end
            if (data_f(1) == f_node2)
                force(numSteps) = force(numSteps) + data_f(3);
            end
        end
        % end of forces
        
        if (debug)
            fprintf(debug_file, '\n');
        end
    end
    
end

if (debug)
    fclose(debug_file);
end

% close dat file
fclose(fid);

disp(['Aabqus file contains ', num2str(i), ' lines']);
disp(['Total number of steps = ', num2str(numSteps)]);

% plot load-displacement curve (note: axis limits are arbitrary)
figure(1)
plot(opening, force)
axis([0 7 0 180])